@@ -9,7 +9,7 @@ from ._ecdf import ecdf
 from ._characteristic_function import ecf
 from ._kernel_transform import kernel_transform
 from ._teager import teager
-from ._kernel_matrix import kernel_matrix
+from ._kernel_matrix import kernel_matrix, euclidian_matrix
 from ._lags_matrix import lags_matrix, covariance_matrix, conv_matrix
 from ._diagnalization import diaganal_average
 from ._tls_turnication import tls_turnication
